resultSet

|  | ## Cheshire3: resultSet Module

Module resultSet

Classes | [hide private]
DeserializationHandler |
RankedResultSet |
SimpleResultSet |
SimpleResultSetItem |
BitmapResultSet |
ArrayResultSet |

Variables | [hide private]
localParser |
localInput |
localHandler |

Variables Details | [hide private]

    ### localParser Value:
        <xml.sax.expatreader.ExpatParser instance at 0xb78fd24c>

    ### localInput Value:
        <xml.sax.xmlreader.InputSource instance at 0xb78fd2ac>

    ### localHandler Value:
        <resultSet.DeserializationHandler instance at 0xb78fddac>